**To delete a dimension**

The following ``delete-dimension`` example deletes a dimension called ``TopicFilterForAuthMessages``. ::

    aws iot delete-dimension \
        --name TopicFilterForAuthMessages

This command produces no output.

For more information, see `Detect Commands <https://docs.aws.amazon.com/iot/latest/developerguide/DetectCommands.html>`__ in the *AWS IoT Developer Guide*.
